# -*- coding: utf-8 -*-

"""
DSuper8 project based on Joe Herman's rpi-film-capture.

Software modified by Manuel Ángel.

User interface redesigned by Manuel Ángel.

config.py: Global server variables.

Latest version: July 2021.
"""

from threading import Lock, Event

# Type of camera used
# Comment on the one that does not apply.
# cameraType = "V1"
cameraType = "HQ"

# Global server variables are defined here.
pool = []
cam = None
img_conn = None
ctrl_conn = None
ctrl_reader = None
pool_lock = Lock()
exitEvent = Event()
nullFile = "/dev/null"

# GPIO pin assignment.
# BCM pin numbering is used.

# Illumination control pin: 0-> off 1-> on.
light_pin = 6

# Stepper motor control pins.
# Direction: 0-> backward 1-> forward.
dir_pin = 19

# Motor activation: 0-> enabled 1-> disabled.
sleep_pin = 13

# Spin pulses.
pulse_pin = 26

# Number of steps required to move forward/backward one frame.
# The stepper motor used is 200 steps per revolution.
# For smooth operation we use 32 microsteps per step, it has the drawback of
# slowness.
# Due to the wheel-pinion mesh, it only takes half a full revolution of the
# engine to advance one frame.
# Therefore we have: number of microsteps = 200 * 32 / 2 = 3200
steps_per_frame = 3200

# They are used to determine the direction of rotation of the motor.
backward = False
forward = True
