# -*- coding: utf-8 -*-

"""
DSuper8 project based on Joe Herman's rpi-film-capture.

Software modified by Manuel Ángel.

User interface redesigned by Manuel Ángel.

nbstreamreader.py: Class for continuous reading of orders from the client.

Latest version: June 2020.
"""

from threading import Thread

from queue import Queue, Empty


# This class is used for the continuous reading of the orders coming from the
# client program.
class NonBlockingStreamReader():

    def __init__(self, stream, event):
        self.strm = stream
        self.que = Queue()
        self.event = event
        self.thr = Thread(target=self.populateQueue,
                          args=(self.strm, self.que, self.event))
        self.thr.daemon = True
        
    # Main reading loop.
    def populateQueue(self, stream, queue, event):
        while not event.is_set():
                line = stream.readline()
                if line:
                    queue.put(line)

    def readline(self, time=None):
        try:
            return self.que.get(block=True, timeout=time)
        except Empty:
            return None


