# -*- coding: utf-8 -*-

"""
DSuper8 project based on Joe Herman's rpi-film-capture.

Software modified by Manuel Ángel.

User interface redesigned by Manuel Ángel.

streamer.py: Class to send images to the client program.

Latest version: June 2020.
"""

from threading import Thread, Event

from struct import pack

from io import BytesIO

# Our own module.
import config


# This class is used to send images to the client program.
class ImageStreamer(Thread):
    def __init__(self, connlock, poollock):
        super(ImageStreamer, self).__init__()
        self.connlock = connlock
        self.poollock = poollock
        self.stream = BytesIO()
        self.event = Event()
        self.terminated = False
        self.imgflag = "s".encode()
        self.exposureTime = 1000
        self.start()

    # Main loop. Runs in a separate thread.
    def run(self):
        while not self.terminated:
            # Waiting for an image to be written to the stream.
            if self.event.wait(1):
                try:
                    with self.connlock:
                        send_a_file(self.imgflag, self.exposureTime,
                                    self.stream)
                finally:
                    self.event.clear()
                    with self.poollock:
                        config.pool.append(self)


def send_a_file(flag, exposureTime, stream):
    config.img_conn.write(flag)
    config.img_conn.write(pack("<i", exposureTime))
    size = stream.tell()
    config.img_conn.write(pack("<L", size))
    config.img_conn.flush()
    stream.seek(0)
    config.img_conn.write(stream.read())
    stream.seek(0)
    stream.truncate()
